############################################################
# FlatCAM: 2D Post-processing for Manufacturing            #
# http://flatcam.org                                       #
# Author: Damian Wrobel <dwrobel@ertelnet.rybnik.pl>       #
# Date: 05/23/2017                                         #
# MIT Licence                                              #
# A setuptools based setup module                          #
############################################################

from setuptools import setup
import glob

NAME = 'flatcam'

setup(
    name=NAME,
    app=['NAME'],
    version='0.8.5',
    description='2D Computer-Aided PCB Manufacturing',
    long_description=('FlatCAM is a program for preparing CNC jobs for making'
                      'PCBs on a CNC router. Among other things, it can take'
                      'a Gerber file generated by your favorite PCB CAD'
                      'program, and create G-Code for Isolation routing.'),
    url='http://flatcam.org/',
    author='Juan Pablo Caram',
    author_email='brainstorm+flatcamfork@nopcode.org',
    license='MIT',

    packages=[
        'flatcam',
        'flatcam/descartes',
        'flatcam/tclCommands'
    ],

    py_modules = [
        "camlib",
        "DblSidedTool",
        "FlatCAMApp",
        "FlatCAMCommon",
        "FlatCAMDraw",
        "FlatCAMGUI",
        "FlatCAMObj",
        "FlatCAMProcess",
        "FlatCAMShell",
        "FlatCAMTool",
        "FlatCAMVersion",
        "FlatCAMWorker",
        "GUIElements",
        "MeasurementTool",
        "ObjectCollection",
        "ObjectUI",
        "PlotCanvas",
        "svgparse",
        "termwidget"
    ],

    install_requires=[
        'numpy>=1.8',
        'scipy',
        'matplotlib>=1.3.1',
        'shapely>=1.3',
        'rtree',
        'svg.path',
        'PyQt5'
    ],
    include_package_data=True,

    data_files=[
        ('share/icons', glob.glob('share/icons/*'))
    ],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: MacOS X",
        "Environment :: X11 Applications :: Qt",
        "Intended Audience :: Manufacturing",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Topic :: Scientific/Engineering :: Electronic Design Automation (EDA)"
    ],
    scripts=['scripts/flatcam']
)
